#!/bin/bash
# -------------------------------------------------------------------------------------------------
# Script: setup-wifi.sh  | Rev: 1.0
# Author: Steve Bashford | Email: steve@worldpossible.org
# Action: Installs wifi-connect service files and adds user SSID/PSWD into service script
# -------------------------------------------------------------------------------------------------

# Set WiFi:
  SSID="$1"
  PSWD="$2"
  SRVF="wifi-connect.service"
  SRVD="/etc/systemd/system"
  WIFF="wifi-toggle.sh"
  WIFD="/etc/network"
  LOGX="wifi.log"

# Input SSID/PSWD running script:
  gid_f(){
    if   [ -z "${SSID}" ]; then
         echo -e "\n  Please enter the SSID of the WiFi Device:\n"
         read SSID
         echo -e "\n  SSID: ${SSID} (select '1' to accept, or any other key to redo)\n"
         read CNFM

         if   [ -z "${CNFM}" ] || [ "${CNFM}" -ne "1" ]; then
              gid_f
         else echo "  SSID: ${SSID} confirmed"
         fi
    else echo "  SSID: ${SSID}"
    fi
  }; gid_f

  gps_f(){
    if   [ -z "${PSWD}" ]; then
         echo -e "\n  Please enter the password of the WiFi Device:\n"
         read PSWD
         echo -e "\n  PSWD: ${PSWD} (select '1' to accept, or any other key to redo)\n"
         read CNFM

         if   [ -z "${CNFM}" ] || [ "${CNFM}" -ne "1" ]; then
              gps_f
         else echo "  PSWD: ${PSWD} confirmed"
         fi
    else echo "  PSWD: ${PSWD}"
    fi
  }; gps_f

# =================================================================================================

# Copy files:
  echo "  Copying service script: ${WIFF}"
  sudo cp -rp "${WIFF}" "${WIFD}/${WIFF}"
  echo "  Copying service file: ${SRVF}"
  sudo cp -rp "${SRVF}" "${SRVD}/${SRVF}"

# Insert SSID/PSWD:
  echo "  Adding SSID to service script:"
  sudo  sed -i "s|MySSID|${SSID}|" "${WIFD}/${WIFF}"
  echo "  Adding PSWD to service script"
  sudo  sed -i "s|MyPSWD|${PSWD}|" "${WIFD}/${WIFF}"

# Starting service:
  "${WIFD}/${WIFF}" on

# Reboot (not used): ==============================================================================
  rbt_f(){
    UPCK=$(cat "${WIFD}/${LOGX}" | grep "up check exceeded")
    FLCK=$(cat "${WIFD}/${LOGX}" | grep "adapter check failed")

    if   [ ! -z "${UPCK}" ]; then exit 0;
    elif [ ! -z "${FLCK}" ]; then exit 0;
    else echo -e "\n  Select any key to reboot (required to enable wifi connect service)\n"
         read -n1; sudo shutdown -r now
  fi
  }
