#!/bin/bash
# -------------------------------------------------------------------------------------------------
# Script: wifi-toggle.sh | Rev: 1.13
# Author: Steve Bashford | Email: steve@worldpossible.org
# Action: Togles WiFi on/off (SSID/PSWD info required)
# -------------------------------------------------------------------------------------------------

# Set WiFi SSID/PSWD (argument: option #1):
  TOGL="$1" # On/off    # Toggle feature on/off (required)
  SSID="$2" # wifi ssid # Optional when default is set
  PSWD="$3" # wifi pswd # Optional when default is set

# Set default wifi SSID/PSWD (script default: option #2):
  SSID_DF="MySSID" # Default ssid <<<<<<<<<<<<< ADD SSID HERE <<<<<<<<<<<<<
  PSWD_DF="MyPSWD" # Default pswd <<<<<<<<<<<<< ADD PSWD HERE <<<<<<<<<<<<<

# Set counters:
  LCNT="0"  # Loop counter
  DLAY="3"  # Script exe(x1) and completion(x2) delays

# Set dir paths:
  LOGX="/etc/network/wifi.log"
  UPDR="/etc/eos-updater"
  UPDS="/usr/share/eos-updater"
  UPDF="eos-autoupdater.conf"

# Validate toggle setting:
  if   [ -z "${TOGL}" ];then
       echo "  Toggle value not set (on/off)"
       exit 0;
  elif [ "${TOGL}" == "on" ] || [ "${TOGL}" == "off" ]; then
       echo "  Toggle: ${TOGL}"
  else echo "  Toggle value invalid (on/off)"
       exit 0;
  fi

# Set default inputs:
    if   [ -z "${SSID}" ]; then SSID="${SSID_DF}"; fi
    if   [ -z "${PSWD}" ]; then PSWD="${PSWD_DF}"; fi

# Set wifi SSID/PSWD (while script is running: option #3):
  gid_f(){
    if   [ -z "${SSID}" ]; then
         echo -e "\n  Please enter the SSID of the WiFi Device:\n"
         read SSID
         echo -e "\n  SSID: ${SSID} (select '1' to accept, or any other key to redo)\n"
         read CNFM

         if   [ -z "${CNFM}" ] || [ "${CNFM}" -ne "1" ]; then
              gid_f
         else echo "  SSID: ${SSID} confirmed"
         fi
    else echo "  SSID: ${SSID}"
    fi
  }; gid_f

  gps_f(){
    if   [ -z "${PSWD}" ]; then
         echo -e "\n  Please enter the password of the WiFi Device:\n"
         read PSWDIN
         echo -e "\n  PSWD: ${PSWDIN} (select '1' to accept, or any other key to redo)\n"
         read CNFM

         if   [ -z "${CNFM}" ] || [ "${CNFM}" -ne "1" ]; then
              gps_f
         else echo "  PSWD: ${PSWDIN} confirmed"
         fi
    else echo "  PSWD: ${PSWD}"
    fi
  }; gps_f

# Functions: ======================================================================================

# Pipe to log:
  ptl_f(){ sudo tee -a "${LOGX}"; }

# Disable os updater:
 dup_f(){
    if   [ ! -d "${UPDR}" ]; then
         sudo mkdir "${UPDR}"
         sudo cp "${UPDS}/${UPDF}" "${UPDR}/"
         sudo sed -i 's/LastAutomaticStep=3/LastAutomaticStep=1/' "${UPDR}/${UPDF}"
    fi
  }; dup_f

# Enable service:
  enb_f(){
    if   [[ $(sudo systemctl is-enabled wifi-connect) != "enabled" ]]; then
         echo "  Enabeling wifi-connect service"
         sudo systemctl enable     wifi-connect
         sudo systemctl daemon-reload
         sudo systemctl is-enabled wifi-connect
         #sudo systemctl start      wifi-connect
         #sudo systemctl is-active  wifi-connect
         #sudo /etc/init.d/network-manager restart
    else echo "  Wifi-connect service already enabled"
    fi
  }

# Disable service:
  dis_f(){
    if   [[ $(sudo systemctl is-enabled wifi-connect) == "enabled" ]]; then
         echo "  Disabeling wifi-connect service"
         sudo systemctl disable    wifi-connect
         sudo systemctl daemon-reload
         sudo systemctl is-enabled wifi-connect
         sudo systemctl stop       wifi-connect
         sudo /etc/init.d/network-manager restart
    else echo "  Wifi-connect service already disabled"
    fi
  }

# Flush action:
  flu_f(){
    echo "  Flushing settings, please wait"
    sudo sync
    sleep $((DLAY * 2))s
    echo "  Install script has completed - done"
  }

# Run Script: =====================================================================================

# Delay wifi init sequence:
  echo -e "\n  Starting wifi adapter check & init sequence, please wait (min:10s | max:40s)\n"
  sleep "${DLAY}"s

# Wifi up check loop:
  lup_f(){
    WFUP=$(sudo nmcli dev wifi | wc -l)

    if   [ "${LCNT}" -ge "12" ]; then
         echo "  WiFi adapter check failed (check wifi doc & reboot) $(date)" | sudo tee "${LOGX}"
         exit 0;
    elif [ -z "${WFUP}" ] || [ "${WFUP}" -lt "2" ]; then
         ((LCNT+=1))
         sleep 3s
         lup_f
    else echo "  WiFi up"
    fi
  }; lup_f

# Check SSID & connection status:
  CNFM=$(sudo nmcli dev wifi | grep "${SSID}" | awk '{print $1}' | head -n1)
  CHCK=$(sudo nmcli connection show --active | grep "${SSID}" | awk '{print $1}' | head -n1)

# Toggle service:
  if   [   -z "${CNFM}" ] && [ "${TOGL}" == "off" ]; then
       dis_f # Disable service wifi-connect
       echo "  SSID not found. Check your SSID, network connection and reboot" | ptl_f
  elif [ ! -z "${CHCK}" ] && [ "${TOGL}" == "on" ]; then
       enb_f # Enable service wifi-connect
       echo "  The SSID is already connected to this device" | ptl_f
  elif [   -z "${CHCK}" ] && [ "${TOGL}" == "on" ]; then
       echo "  Enabling wifi connection: ${SSID} $(date)" | ptl_f
       sudo nmcli dev wifi connect "${SSID}" password "${PSWD}"
       enb_f # Enable service wifi-connect
       flu_f # Flush action
  elif [ ! -z "${CHCK}" ] && [ "${TOGL}" == "off" ]; then
       echo "  Disabling wifi connection $(date)" | ptl_f
       sudo nmcli connection delete id "${SSID}"
       dis_f # Disable service wifi-connect
       flu_f # Flush action
  else echo "  Unexpected SSID status"
  fi
